@@ -1,3 +1,4 @@
+
 # -*- coding: utf-8 -*-
 import os
 import platform
@@ -179,6 +180,17 @@ class ADB(object):
                 raise AdbError(stdout, stderr)
         return stdout
 
+    def close_proc_pipe(self, proc):
+        """close stdin/stdout/stderr of subprocess.Popen."""
+
+        def close_pipe(pipe):
+            if pipe:
+                pipe.close()
+
+        close_pipe(proc.stdin)
+        close_pipe(proc.stdout)
+        close_pipe(proc.stderr)
+
     def devices(self, state=None):
         """
         Perform `adb devices` command and return the list of adb devices
@@ -710,6 +722,21 @@ class ADB(object):
         else:
             return not("No such file or directory" in out)
 
+    def file_size(self, filepath):
+        """
+        Get the file size
+        
+        Args:
+            filepath: path to the file
+
+        Returns:
+            The file size
+        """
+        out = self.shell(["ls", "-l", filepath])
+        file_size = int(out.split()[3])
+        return file_size
+
+
     def _cleanup_forwards(self):
         """
         Remove the local forward ports
@@ -735,7 +762,7 @@ class ADB(object):
             if self.sdk_version >= SDK_VERISON_NEW:
                 line_breaker = os.linesep
             else:
-                line_breaker = b'\r' + os.linesep
+                line_breaker = '\r' + os.linesep
             self._line_breaker = line_breaker
         return self._line_breaker
 
