@@ -19,32 +19,47 @@ Device Setup APIs
 """
 
 
+def init_device(platform="Android", uuid=None, **kwargs):
+    """
+    Initialize device if not yet, and set as current device.
+
+    :param platform: Android, IOS or Windows
+    :param uuid: uuid for target device, e.g. serialno for Android, handle for Windows, uuid for iOS
+    :param kwargs: Optional platform specific keyword args, e.g. `cap_method=JAVACAP` for Android
+    :return: device instance
+    """
+    cls = import_device_cls(platform)
+    dev = cls(uuid, **kwargs)
+    for index, instance in enumerate(G.DEVICE_LIST):
+        if dev.uuid == instance.uuid:
+            G.LOGGING.warn("Device:%s updated %s -> %s" % (dev.uuid, instance, dev))
+            G.DEVICE_LIST[index] = dev
+            break
+    else:
+        G.add_device(dev)
+    return dev
+
+
 def connect_device(uri):
     """
-    Initialize device with uri and set the device as the current one.
+    Initialize device with uri, and set as current device.
 
     :param uri: an URI where to connect to device, e.g. `android://adbhost:adbport/serialno?param=value&param2=value2`
     :return: device instance
     :Example:
         * ``android:///`` # local adb device using default params
-        * ``android://adbhost:adbport/1234566?cap_method=javacap&touch_method=adb``  # remote adb device using custom params
+        * ``android://adbhost:adbport/1234566?cap_method=javacap&touch_method=adb``  # remote device using custom params
         * ``windows:///`` # local Windows application
         * ``ios:///`` # iOS device
-
-    :platforms: Android, iOS, Windows
     """
     d = urlparse(uri)
     platform = d.scheme
     host = d.netloc
     uuid = d.path.lstrip("/")
     params = dict(parse_qsl(d.query))
-
     if host:
         params["host"] = host.split(":")
-
-    cls = import_device_cls(platform)
-    dev = cls(uuid, **params)
-    G.add_device(dev)
+    dev = init_device(platform, uuid, **params)
     return dev
 
 
@@ -53,40 +68,52 @@ def device():
     Return the current active device.
 
     :return: current device instance
-    :platforms: Android, iOS, Windows
     """
     return G.DEVICE
 
 
-@on_platform(["Android", "Windows", "IOS"])
-def set_current(index):
+def set_current(idx):
     """
     Set current active device.
 
-    :param index: index of initialized device instance
-    :raise IndexError: raised when device index is out of device list
+    :param idx: uuid or index of initialized device instance
+    :raise IndexError: raised when device idx is not found
     :return: None
     :platforms: Android, iOS, Windows
     """
-    try:
-        G.DEVICE = G.DEVICE_LIST[index]
-    except IndexError:
-        raise IndexError("device index out of range: %s/%s" % (index, len(G.DEVICE_LIST)))
+
+    dev_dict = {dev.uuid: dev for dev in G.DEVICE_LIST}
+    if idx in dev_dict:
+        current_dev = dev_dict[idx]
+    elif isinstance(idx, int) and idx < len(G.DEVICE_LIST):
+        current_dev = G.DEVICE_LIST[idx]
+    else:
+        raise IndexError("device idx not found in: %s or %s" % (
+            list(dev_dict.keys()), list(range(len(G.DEVICE_LIST)))))
+    G.DEVICE = current_dev
 
 
-def auto_setup(filepath):
+def auto_setup(basedir=None, devices=None, logdir=None, project_root=None):
     """
-    Auto setup G.BASEDIR and try connect android device if not connected to any device.
+    Auto setup running env and try connect android device if not device connected.
     """
-    if filepath:
-        dirname = os.path.dirname(filepath)
-        if dirname not in G.BASEDIR:
-            G.BASEDIR.append(dirname)
-    if not device():
+    if devices:
+        for dev in devices:
+            connect_device(dev)
+    else:
         try:
             connect_device("Android:///")
         except IndexError:
             pass
+    if basedir:
+        if os.path.isfile(basedir):
+            basedir = os.path.dirname(basedir)
+        if basedir not in G.BASEDIR:
+            G.BASEDIR.append(basedir)
+    if logdir:
+        set_logdir(logdir)
+    if project_root:
+        ST.PROJECT_ROOT = project_root
 
 
 """
