@@ -23,11 +23,25 @@ from airtest.utils.logger import get_logger
 
 # roatations of ios
 from wda import LANDSCAPE, PORTRAIT, LANDSCAPE_RIGHT, PORTRAIT_UPSIDEDOWN
+from wda import WDAError
 
 
 logger = get_logger(__name__)
 DEFAULT_ADDR = "http://localhost:8100/"
 
+# retry when saved session failed
+def retry_session(func):
+    def wrapper(self, *args, **kwargs):
+        try:
+            return func(self, *args, **kwargs)
+        except WDAError as err:
+            # 6 : Session does not exist
+            if err.status == 6:
+                self._fetchNewSession()
+                return func(self, *args, **kwargs)
+            else:
+                raise err
+    return wrapper
 
 class IOS(Device):
     """ios client
@@ -38,7 +52,13 @@ class IOS(Device):
 
     def __init__(self, addr=DEFAULT_ADDR):
         super(IOS, self).__init__()
-        self.addr = addr
+
+        # if none or empty, use default addr
+        self.addr = addr or DEFAULT_ADDR
+
+        # fit wda format, make url start with http://
+        if not self.addr.startswith("http://"):
+            self.addr = "http://" + addr
 
         """here now use these supported cap touch and ime method"""
         self.cap_method = CAP_METHOD.WDACAP
@@ -49,7 +69,7 @@ class IOS(Device):
         # init wda session, updata when start app
         # use to click/swipe/close app/get wda size
         wda.DEBUG = False
-        self.driver = wda.Client(addr)
+        self.driver = wda.Client(self.addr)
 
         # record device's width
         self._size = {'width': None, 'height': None}
@@ -58,17 +78,25 @@ class IOS(Device):
         self.defaultSession = None
 
         # start up RotationWatcher with default session
-        self.rotation_watcher = RotationWatcher(self.session)
+        self.rotation_watcher = RotationWatcher(self)
 
         # fake minitouch to simulate swipe
         self.minitouch = fakeMiniTouch(self)
 
+    @property
+    def uuid(self):
+        return self.addr
+
     @property
     def session(self):
         if not self.defaultSession:
             self.defaultSession = self.driver.session()
         return self.defaultSession
 
+    def _fetchNewSession(self):
+        self.defaultSession = self.driver.session()
+
+    @retry_session
     def window_size(self):
         """
             return window size
@@ -78,6 +106,7 @@ class IOS(Device):
         return self.session.window_size()
 
     @property
+    @retry_session
     def orientation(self):
         """
             return device oritantation status
@@ -178,6 +207,7 @@ class IOS(Device):
 
         return screen
 
+    @retry_session
     def touch(self, pos, times=1, duration=0.01):
         # trans pos of click
         pos = self._touch_point_by_orientation(pos)
@@ -191,7 +221,7 @@ class IOS(Device):
             for _ in range(times):
                 self.session.tap(x, y)
 
-    def swipe(self, fpos, tpos, duration=0.5):
+    def swipe(self, fpos, tpos, duration=0.5, steps=5, fingers=1):
         # trans pos of swipe
         fx, fy = self._touch_point_by_orientation(fpos)
         tx, ty = self._touch_point_by_orientation(tpos)
@@ -205,6 +235,7 @@ class IOS(Device):
             raise NotImplementedError
         self.home()
 
+    @retry_session
     def text(self, text, enter=True):
         """bug in wda for now"""
         if enter:
@@ -221,6 +252,7 @@ class IOS(Device):
         raise NotImplementedError
 
     def start_app(self, package, activity=None):
+        self.defaultSession = None
         self.driver.session(package)
 
     def stop_app(self, package):
