@@ -1,4 +1,5 @@
 # _*_ coding:UTF-8 _*_
+
 import os
 import sys
 import json
@@ -49,7 +50,11 @@ class AirtestLogger(object):
             depth = 1
 
         if self.logfd:
-            self.logfd.write(json.dumps({'tag': tag, 'depth': depth, 'time': time.strftime("%Y-%m-%d %H:%M:%S"), 'data': data}, default=self._dumper) + '\n')
+            try:
+                log_data = json.dumps({'tag': tag, 'depth': depth, 'time': time.strftime("%Y-%m-%d %H:%M:%S"), 'data': data}, default=self._dumper)
+            except UnicodeDecodeError:
+                log_data = json.dumps({'tag': tag, 'depth': depth, 'time': time.strftime("%Y-%m-%d %H:%M:%S"), 'data': repr(data).decode(sys.getfilesystemencoding())}, default=self._dumper)
+            self.logfd.write(log_data + '\n')
             self.logfd.flush()
 
     def handle_stacked_log(self):
@@ -72,7 +77,7 @@ def Logwrap(f, logger):
         try:
             res = f(*args, **kwargs)
         except Exception as e:
-            data = {"traceback": traceback.format_exc(), "time_used": time.time() - start, "error_str": str(e)}
+            data = {"traceback": traceback.format_exc(), "time_used": time.time() - start, "error_str": repr(e).encode(sys.getfilesystemencoding())}
             fndata.update(data)
             fndata.update(LOGGER.extra_log)
             LOGGER.log("error", fndata)
